summaryrefslogtreecommitdiffstats
path: root/libkdepim/ksubscription.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/ksubscription.cpp')
-rw-r--r--libkdepim/ksubscription.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/libkdepim/ksubscription.cpp b/libkdepim/ksubscription.cpp
index f1c5b657a..cff384f2b 100644
--- a/libkdepim/ksubscription.cpp
+++ b/libkdepim/ksubscription.cpp
@@ -32,7 +32,7 @@
KGroupInfo::KGroupInfo(const TQString &name, const TQString &description,
bool newGroup, bool subscribed,
- Status status, TQString path)
+ tqStatus status, TQString path)
: name(name), description(description),
newGroup(newGroup), subscribed(subscribed),
status(status), path(path)
@@ -105,7 +105,7 @@ void GroupItem::setOn( bool on )
//------------------------------------------------------------------------------
void GroupItem::stateChange( bool on )
{
// delegate to parent
if ( !mIgnoreStateChange )
mBrowser->changeItemState(this, on);
}
@@ -133,7 +133,7 @@ void GroupItem::setVisible( bool b )
TQListViewItem::setVisible(b);
else
{
- // leave it visible so that children remain visible
+ // leave it visible so that tqchildren remain visible
setOpen(true);
setEnabled(false);
}
@@ -156,8 +156,8 @@ void GroupItem::setVisible( bool b )
for ( ; it.current(); ++it)
{
// move the checkitem to top
- TQListViewItem* parent = it.current()->parent();
- if (parent) parent->takeItem(it.current());
+ TQListViewItem* tqparent = it.current()->tqparent();
+ if (tqparent) tqparent->takeItem(it.current());
listView()->insertItem(it.current());
}
TQListViewItem::setVisible(false);
@@ -206,9 +206,9 @@ void GroupItem::setup()
//=============================================================================
-KSubscription::KSubscription( TQWidget *parent, const TQString &caption,
+KSubscription::KSubscription( TQWidget *tqparent, const TQString &caption,
KAccount * acct, int buttons, const TQString &user1, bool descriptionColumn )
- : KDialogBase( parent, 0, true, caption, buttons | Help | Ok | Cancel, Ok,
+ : KDialogBase( tqparent, 0, true, caption, buttons | Help | Ok | Cancel, Ok,
true, i18n("Reload &List"), user1 ),
mAcct( acct )
{
@@ -445,10 +445,10 @@ void KSubscription::changeItemState( GroupItem* item, bool on )
{
if (!itemInListView(unsubView, item->info()))
{
- TQListViewItem *p = item->parent();
+ TQListViewItem *p = item->tqparent();
while (p)
{
- // make sure all parents are subscribed
+ // make sure all tqparents are subscribed
GroupItem* pi = static_cast<GroupItem*>(p);
if (pi->isCheckItem() && !pi->isOn())
{
@@ -457,7 +457,7 @@ void KSubscription::changeItemState( GroupItem* item, bool on )
pi->setIgnoreStateChange(false);
new GroupItem(subView, pi->info(), this);
}
- p = p->parent();
+ p = p->tqparent();
}
new GroupItem(subView, item->info(), this);
}
@@ -511,7 +511,7 @@ void KSubscription::filterChanged( TQListViewItem* item, const TQString & text )
continue;
}
if ( !text.isEmpty() &&
- gr->text(0).find(text, 0, false) == -1)
+ gr->text(0).tqfind(text, 0, false) == -1)
{
// searchfield
gr->setVisible(false);
@@ -560,7 +560,7 @@ void KSubscription::restoreOriginalParent()
{
TQListViewItem* origParent = static_cast<GroupItem*>(it.current())->
originalParent();
- if (origParent && origParent != it.current()->parent())
+ if (origParent && origParent != it.current()->tqparent())
{
// remember this to avoid messing up the iterator
move.append(it.current());
@@ -569,7 +569,7 @@ void KSubscription::restoreOriginalParent()
TQPtrListIterator<TQListViewItem> it2( move );
for ( ; it2.current(); ++it2)
{
// restore the original parent
TQListViewItem* origParent = static_cast<GroupItem*>(it2.current())->
originalParent();
groupView->takeItem(it2.current());
@@ -612,12 +612,12 @@ void KSubscription::slotLoadingComplete()
noTreeCB->setEnabled(true);
subCB->setEnabled(true);
// remember the correct parent
TQListViewItemIterator it(groupView);
for ( ; it.current(); ++it)
{
static_cast<GroupItem*>(it.current())->
- setOriginalParent( it.current()->parent() );
+ setOriginalParent( it.current()->tqparent() );
}
emit listChanged();
@@ -105,7 +105,7 @@ void GroupItem::setOn( bool on )
void GroupItem::stateChange( bool on )
{
- // delegate to parent
+ // delegate to tqparent
if ( !mIgnoreStateChange )
mBrowser->changeItemState(this, on);
@@ -569,7 +569,7 @@ void KSubscription::restoreOriginalParent()
for ( ; it2.current(); ++it2)
{
- // restore the original parent
+ // restore the original tqparent
TQListViewItem* origParent = static_cast<GroupItem*>(it2.current())->
originalParent();
@@ -612,12 +612,12 @@ void KSubscription::slotLoadingComplete()
noTreeCB->setEnabled(true);
subCB->setEnabled(true);
- // remember the correct parent
+ // remember the correct tqparent
TQListViewItemIterator it(groupView);
for ( ; it.current(); ++it)